elapsed

Function elapsed 

pub fn elapsed(earlier: Monotonic) -> Duration
Available on crate feature std only.
Returns the Duration elapsed since earlier.

Shortcut for Monotonic::elapsed. The argument is the Monotonic captured at the start of the interval; the return value is the time from then until now.

Examples

use clock_lib as clock;

let start = clock::now();
// ... work ...
let took = clock::elapsed(start);